@@ -1,6 +1,6 @@
 """Main Plato module providing the most used library members."""
 
 from .context import seed
-from .formclasses import derivedfield, formclass, sample
+from .formclasses import InitVar, derivedfield, formclass, sample
 from .providers import Provider
 from .providers.common import Shared
